import { defu } from "defu";
import { applyDefaults } from "untyped";
export function definePgTExtension(definition) {
    // Normalize definition and meta
    if (!definition.meta)
        definition.meta = {};
    if (definition.meta.configKey === undefined)
        definition.meta.configKey = definition.meta.name;
    // Resolves module options from inline options, [configKey] in nuxt.config, defaults and schema
    async function getOptions(pgt, inlineOptions) {
        const configKey = definition.meta?.configKey || definition.meta?.name || "unknown", _defaults = definition.defaults instanceof Function ? definition.defaults(pgt) : definition.defaults;
        let _options = defu(inlineOptions, pgt.PgTConfig[configKey], _defaults);
        if (definition.schema)
            _options = (await applyDefaults(definition.schema, _options));
        return _options;
    }
    // Module format is always a simple function
    async function normalizedModule(inlineOptions, pgt) {
        // Resolve module and options
        const _options = await getOptions(pgt, inlineOptions);
        // eslint-disable-next-line unicorn/no-null
        await definition.setup?.call(null, _options, pgt);
    }
    // Define getters for options and meta
    normalizedModule.getMeta = () => Promise.resolve(definition.meta);
    normalizedModule.getOptions = getOptions;
    return normalizedModule;
}
//# sourceMappingURL=definePgTExtension.js.map